@@ -2,23 +2,35 @@ package org.gcube.portlets.user.td.expressionwidget.shared.model.leaf;
 
 import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
 
+/**
+ * 
+ * @author Giancarlo Panichi
+ * 
+ *
+ */
 public class C_ColumnReferencePlaceholder extends C_Leaf {
 
 	private static final long serialVersionUID = 275747262118236529L;
 	protected String id = "ColumnReferencePlaceholder";
 	protected String columnId;
+	protected String label;
 	protected ColumnDataType dataType;
 
-	public C_ColumnReferencePlaceholder(){
-		
-	}
-	
-	public C_ColumnReferencePlaceholder(ColumnDataType dataType, String columnId) {
-		this.dataType = dataType;
-		this.columnId = columnId;
+	public C_ColumnReferencePlaceholder() {
 
 	}
-	
+
+	public C_ColumnReferencePlaceholder(ColumnDataType dataType,
+			String columnId, String label) {
+		this.dataType = dataType;
+		this.columnId = columnId;
+		if (dataType != null && columnId != null && label != null) {
+			this.readableExpression = "$" + label + "[" + dataType.getLabel()
+					+ "]";
+		}
+
+	}
+
 	@Override
 	public String getId() {
 		return id;
@@ -32,6 +44,14 @@ public class C_ColumnReferencePlaceholder extends C_Leaf {
 		this.columnId = columnId;
 	}
 
+	public String getLabel() {
+		return label;
+	}
+
+	public void setLabel(String label) {
+		this.label = label;
+	}
+
 	public ColumnDataType getDataType() {
 		return dataType;
 	}
@@ -42,8 +62,9 @@ public class C_ColumnReferencePlaceholder extends C_Leaf {
 
 	@Override
 	public String toString() {
-		return "ColumnReferencePlaceholder [id=" + id + ", columnId="
-				+ columnId + ", dataType=" + dataType + "]";
+		return "C_ColumnReferencePlaceholder [id=" + id + ", columnId="
+				+ columnId + ", label=" + label + ", dataType=" + dataType
+				+ "]";
 	}
 
 }
